@@ -29,8 +29,9 @@
  * This should be incremented at least each time a new symbol is added
  * to the header.
  */
-#define OUT123_API_VERSION 1
+#define OUT123_API_VERSION 2
 
+#ifndef MPG123_EXPORT
 /** Defines needed for MS Visual Studio(tm) DLL builds.
  * Every public function must be prefixed with MPG123_EXPORT. When building 
  * the DLL ensure to define BUILD_MPG123_DLL. This makes the function accessible
@@ -50,6 +51,7 @@
 #define MPG123_EXPORT
 #endif
 #endif
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -110,6 +112,11 @@ enum out123_parms
  * The value returned by out123_getparam() might be different if the audio
  * backend changed it (to be unique among clients, p.ex.).
  * TODO: The name provided here is used as prefix in diagnostic messages. */
+,	OUT123_BINDIR /**< string, path to a program binary directory to use
+ * as starting point in the search for the output module directory
+ * (e.g. ../lib/mpg123 or ./plugins). The environment variable MPG123_MODDIR
+ * is always tried first and the in-built installation path last.
+ */
 };
 
 /** Flags to tune out123 behaviour */
@@ -118,7 +125,7 @@ enum out123_flags
 	OUT123_HEADPHONES       = 0x01 /**< output to headphones (if supported) */
 ,	OUT123_INTERNAL_SPEAKER = 0x02 /**< output to speaker (if supported) */
 ,	OUT123_LINE_OUT         = 0x04 /**< output to line out (if supported) */
-,	OUT123_QUIET               = 0x08 /**< no printouts to stdandard error */
+,	OUT123_QUIET               = 0x08 /**< no printouts to standard error */
 ,	OUT123_KEEP_PLAYING        = 0x10 /**<
  *  When this is set (default), playback continues in a loop when the device
  *  does not consume all given data at once. This happens when encountering
@@ -126,7 +133,7 @@ enum out123_flags
  *  functions.
  *  Note that this flag is meaningless when the optional buffer is employed,
  *  There, your program will always block until the buffer completely took
- *  over the data given to it via out123_play(), unless a communcation error
+ *  over the data given to it via out123_play(), unless a communication error
  *  arises.
  */
 };
@@ -182,6 +189,7 @@ enum out123_error
 ,	OUT123_ARG_ERROR /**< some bad function arguments supplied */
 ,	OUT123_BAD_PARAM /**< unknown parameter code */
 ,	OUT123_SET_RO_PARAM /**< attempt to set read-only parameter */
+,	OUT123_BAD_HANDLE /**< bad handle pointer (NULL, usually) */
 ,	OUT123_ERRCOUNT /**< placeholder for shaping arrays */
 };
 
@@ -194,6 +202,8 @@ MPG123_EXPORT
 const char* out123_strerror(out123_handle *ao);
 
 /** Get the plain errcode intead of a string.
+ * Note that this used to return OUT123_ERR instead of
+ * OUT123_BAD_HANDLE in case of ao==NULL before mpg123-1.23.5 .
  * \param ao handle
  * \return error code recorded in handle or OUT123_BAD_HANDLE
  */
@@ -574,7 +584,5 @@ int out123_getformat( out123_handle *ao
 }
 #endif
 
-#undef MPG123_EXPORT
-
 #endif
 
